@@ -1,8 +1,11 @@
 /*
  * Copyright (C) 2009 Nokia Corporation.
+ * Copyright (C) 2012 Intel Corporation
  *
- * Authors: Zeeshan Ali (Khattak) <zeeshan.ali@nokia.com>
- *                                <zeeshanak@gnome.org>
+ * Authors: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
+ *                                <zeeshan.ali@nokia.com>
+ *          Krzesimir Nowak <krnowak@openismus.com>
+ *          Christophe Guiraud <christophe.guiraud@intel.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,8 +19,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -30,8 +33,12 @@
 #include <string.h>
 
 #include "gupnp-didl-lite-container.h"
+#include "gupnp-didl-lite-object-private.h"
+#include "gupnp-didl-lite-createclass.h"
+#include "gupnp-didl-lite-createclass-private.h"
 #include "xml-util.h"
 
+
 G_DEFINE_TYPE (GUPnPDIDLLiteContainer,
                gupnp_didl_lite_container,
                GUPNP_TYPE_DIDL_LITE_OBJECT);
@@ -40,7 +47,9 @@ enum {
         PROP_0,
         PROP_SEARCHABLE,
         PROP_CHILD_COUNT,
-        PROP_STORAGE_USED
+        PROP_STORAGE_USED,
+        PROP_CONTAINER_UPDATE_ID,
+        PROP_TOTAL_DELETED_CHILD_COUNT
 };
 
 static void
@@ -75,6 +84,18 @@ gupnp_didl_lite_container_get_property (GObject    *object,
                         (value,
                          gupnp_didl_lite_container_get_storage_used (container));
                 break;
+        case PROP_CONTAINER_UPDATE_ID:
+                g_value_set_uint
+                              (value,
+                               gupnp_didl_lite_container_get_container_update_id
+                                        (container));
+                break;
+        case PROP_TOTAL_DELETED_CHILD_COUNT:
+                g_value_set_uint
+                        (value,
+                         gupnp_didl_lite_container_get_total_deleted_child_count
+                                        (container));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -108,6 +129,16 @@ gupnp_didl_lite_container_set_property (GObject      *object,
                                         (container,
                                          g_value_get_int64 (value));
                 break;
+        case PROP_CONTAINER_UPDATE_ID:
+                gupnp_didl_lite_container_set_container_update_id
+                                        (container,
+                                         g_value_get_uint (value));
+                break;
+        case PROP_TOTAL_DELETED_CHILD_COUNT:
+                gupnp_didl_lite_container_set_total_deleted_child_count
+                                        (container,
+                                         g_value_get_uint (value));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -179,6 +210,44 @@ gupnp_didl_lite_container_class_init (GUPnPDIDLLiteContainerClass *klass)
                                      G_PARAM_STATIC_NAME |
                                      G_PARAM_STATIC_NICK |
                                      G_PARAM_STATIC_BLURB));
+
+        /**
+         * GUPnPDIDLLiteContainer:container-update-id:
+         *
+         * Update ID of this container.
+         **/
+        g_object_class_install_property
+                             (object_class,
+                              PROP_CONTAINER_UPDATE_ID,
+                              g_param_spec_uint ("container-update-id",
+                                                 "ContainerUpdateID",
+                                                 "Update ID of this container.",
+                                                 0,
+                                                 G_MAXUINT,
+                                                 0,
+                                                 G_PARAM_READWRITE |
+                                                 G_PARAM_STATIC_NAME |
+                                                 G_PARAM_STATIC_NICK |
+                                                 G_PARAM_STATIC_BLURB));
+
+        /**
+         * GUPnPDIDLLiteContainer:total-deleted-child-count:
+         *
+         * Total deleted child count of this container.
+         **/
+        g_object_class_install_property
+             (object_class,
+              PROP_TOTAL_DELETED_CHILD_COUNT,
+              g_param_spec_uint ("total-deleted-child-count",
+                                 "TotalDeletedChildCOunt",
+                                 "Total deleted child count of this container.",
+                                 0,
+                                 G_MAXUINT,
+                                 0,
+                                 G_PARAM_READWRITE |
+                                 G_PARAM_STATIC_NAME |
+                                 G_PARAM_STATIC_NICK |
+                                 G_PARAM_STATIC_BLURB));
 }
 
 /**
@@ -226,14 +295,113 @@ gupnp_didl_lite_container_get_child_count (GUPnPDIDLLiteContainer *container)
         return xml_util_get_int_attribute (xml_node, "childCount", -1);
 }
 
+/**
+ * gupnp_didl_lite_container_get_container_update_id:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Get the container update ID of the @container.
+ *
+ * Return value: The container update ID of the @container.
+ **/
+guint
+gupnp_didl_lite_container_get_container_update_id
+                                        (GUPnPDIDLLiteContainer *container)
+{
+        xmlNode *xml_node;
+
+        g_return_val_if_fail (container != NULL, 0);
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container), 0);
+
+        xml_node = gupnp_didl_lite_object_get_xml_node
+                                (GUPNP_DIDL_LITE_OBJECT (container));
+
+        return xml_util_get_uint_child_element (xml_node,
+                                                "containerUpdateID",
+                                                0);
+}
+
+/**
+ * gupnp_didl_lite_container_container_update_id_is_set:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Get whether the container update ID of the @container is set.
+ *
+ * Return value: %TRUE if update ID is set, otherwise %FALSE
+ **/
+gboolean
+gupnp_didl_lite_container_container_update_id_is_set
+                                        (GUPnPDIDLLiteContainer *container)
+{
+        const char *content;
+        xmlNode *xml_node;
+
+        g_return_val_if_fail (container != NULL, FALSE);
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container), FALSE);
+
+        xml_node = gupnp_didl_lite_object_get_xml_node
+                                        (GUPNP_DIDL_LITE_OBJECT (container));
+        content = xml_util_get_child_element_content (xml_node,
+                                                      "containerUpdateID");
+        return content != NULL;
+}
+
+/**
+ * gupnp_didl_lite_container_get_total_deleted_child_count:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Get the total deleted child count of the @container.
+ *
+ * Return value: The total deleted child count of the @container.
+ **/
+guint
+gupnp_didl_lite_container_get_total_deleted_child_count
+                                        (GUPnPDIDLLiteContainer *container)
+{
+        xmlNode *xml_node;
+
+        g_return_val_if_fail (container != NULL, 0);
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container), 0);
+
+        xml_node = gupnp_didl_lite_object_get_xml_node
+                                (GUPNP_DIDL_LITE_OBJECT (container));
+
+        return xml_util_get_uint_child_element (xml_node,
+                                                "totalDeletedChildCount",
+                                                0);
+}
+
+/**
+ * gupnp_didl_lite_container_total_deleted_child_count_is_set:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Get whether the total deleted child conut of the @container is set.
+ *
+ * Return value: %TRUE if property is set, otherwise %FALSE
+ **/
+gboolean
+gupnp_didl_lite_container_total_deleted_child_count_is_set
+                                        (GUPnPDIDLLiteContainer *container)
+{
+        const char *content;
+        xmlNode *xml_node;
+
+        g_return_val_if_fail (container != NULL, FALSE);
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container), FALSE);
+
+        xml_node = gupnp_didl_lite_object_get_xml_node
+                                        (GUPNP_DIDL_LITE_OBJECT (container));
+        content = xml_util_get_child_element_content (xml_node,
+                                                      "totalDeletedChildCount");
+        return content != NULL;
+}
 /**
  * gupnp_didl_lite_container_get_create_classes:
  * @container: #GUPnPDIDLLiteContainer
  *
- * Gets the list of create classes of the @object.
+ * Gets the list of create classes of the @container.
  *
  * Returns: (element-type utf8) (transfer full): The list of create classes
- * belonging to @object, or %NULL.
+ * belonging to @container, or %NULL.
  * #g_list_free the returned list after usage and #g_free each string in it.
  **/
 GList *
@@ -255,6 +423,7 @@ gupnp_didl_lite_container_get_create_classes (GUPnPDIDLLiteContainer *container)
                 xmlNode *node;
 
                 node = (xmlNode *) l->data;
+
                 if (node->children != NULL) {
                     create_class = g_strdup ((const char *) node->children->content);
 
@@ -267,14 +436,61 @@ gupnp_didl_lite_container_get_create_classes (GUPnPDIDLLiteContainer *container)
         return ret;
 }
 
+/**
+ * gupnp_didl_lite_container_get_create_classes_full:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Gets the list of create classes of the @container.
+ *
+ * Returns: (element-type GUPnPDIDLLiteCreateClass*) (transfer full): The list
+ * of create classes belonging to @container, or %NULL.
+ * #g_list_free the returned list after usage and unref each object in it.
+ **/
+GList *
+gupnp_didl_lite_container_get_create_classes_full (
+                                            GUPnPDIDLLiteContainer *container)
+{
+        GList *cc_list = NULL;
+        GList *ret = NULL;
+        GList *l;
+
+        g_return_val_if_fail (container != NULL, NULL);
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container), NULL);
+
+        cc_list = gupnp_didl_lite_object_get_properties (
+                                           GUPNP_DIDL_LITE_OBJECT (container),
+                                           "createClass");
+
+        for (l = cc_list; l; l = l->next) {
+                GUPnPDIDLLiteCreateClass *cc;
+                xmlNode *cc_node;
+                GUPnPXMLDoc *cc_doc;
+
+                cc_node = (xmlNode *) l->data;
+                if (!cc_node->children)
+                        continue;
+
+                cc_doc = gupnp_didl_lite_object_get_gupnp_xml_doc (
+                                           GUPNP_DIDL_LITE_OBJECT (container));
+
+                cc = gupnp_didl_lite_create_class_new_from_xml (cc_node, cc_doc);
+
+                ret = g_list_append (ret, cc);
+        }
+
+        g_list_free (cc_list);
+
+        return ret;
+}
+
 /**
  * gupnp_didl_lite_container_get_search_classes:
  * @container: #GUPnPDIDLLiteContainer
  *
- * Gets the list of search classes of the @object.
+ * Gets the list of search classes of the @container.
  *
  * Return value: (element-type utf8) (transfer full): The list of search classes
- * belonging to @object, or %NULL. #g_list_free the returned list after usage
+ * belonging to @container, or %NULL. #g_list_free the returned list after usage
  * and #g_free each string in it.
  **/
 GList *
@@ -403,12 +619,130 @@ gupnp_didl_lite_container_set_child_count (GUPnPDIDLLiteContainer *container,
         g_object_notify (G_OBJECT (container), "child-count");
 }
 
+/**
+ * gupnp_didl_lite_container_set_container_update_id:
+ * @container: #GUPnPDIDLLiteContainer
+ * @update_id: The container update ID
+ *
+ * Set the container update ID of the @container.
+ **/
+void
+gupnp_didl_lite_container_set_container_update_id
+                                        (GUPnPDIDLLiteContainer *container,
+                                         guint                   update_id)
+{
+        xmlNode *xml_node;
+        xmlNsPtr upnp_ns;
+        GUPnPXMLDoc *xml_doc;
+        char *str;
+        GUPnPDIDLLiteObject *self_as_object;
+
+        g_return_if_fail (container != NULL);
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container));
+
+        self_as_object = GUPNP_DIDL_LITE_OBJECT (container);
+        xml_node = gupnp_didl_lite_object_get_xml_node (self_as_object);
+        xml_doc = gupnp_didl_lite_object_get_gupnp_xml_doc (self_as_object);
+        upnp_ns = gupnp_didl_lite_object_get_upnp_namespace (self_as_object);
+
+        str = g_strdup_printf ("%u", update_id);
+        xml_util_set_child (xml_node,
+                            upnp_ns,
+                            xml_doc->doc,
+                            "containerUpdateID",
+                            str);
+        g_free (str);
+
+        g_object_notify (G_OBJECT (container), "container-update-id");
+}
+
+/**
+ * gupnp_didl_lite_container_unset_container_update_id:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Unset the container update ID property of the @container.
+ **/
+void
+gupnp_didl_lite_container_unset_container_update_id
+                                        (GUPnPDIDLLiteContainer *container)
+{
+        xmlNode *xml_node;
+
+        g_return_if_fail (container != NULL);
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container));
+
+        xml_node = gupnp_didl_lite_object_get_xml_node
+                                        (GUPNP_DIDL_LITE_OBJECT (container));
+        xml_util_unset_child (xml_node, "containerUpdateID");
+
+        g_object_notify (G_OBJECT (container), "container-update-id");
+}
+
+/**
+ * gupnp_didl_lite_container_set_total_deleted_child_count:
+ * @container: #GUPnPDIDLLiteContainer
+ * @count: The container update ID
+ *
+ * Set the container update ID of the @container.
+ **/
+void
+gupnp_didl_lite_container_set_total_deleted_child_count
+                                        (GUPnPDIDLLiteContainer *container,
+                                         guint                   count)
+{
+        xmlNode *xml_node;
+        xmlNsPtr upnp_ns;
+        GUPnPXMLDoc *xml_doc;
+        char *str;
+        GUPnPDIDLLiteObject *self_as_object;
+
+        g_return_if_fail (container != NULL);
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container));
+
+        self_as_object = GUPNP_DIDL_LITE_OBJECT (container);
+        xml_node = gupnp_didl_lite_object_get_xml_node (self_as_object);
+        xml_doc = gupnp_didl_lite_object_get_gupnp_xml_doc (self_as_object);
+        upnp_ns = gupnp_didl_lite_object_get_upnp_namespace (self_as_object);
+
+        str = g_strdup_printf ("%u", count);
+        xml_util_set_child (xml_node,
+                            upnp_ns,
+                            xml_doc->doc,
+                            "totalDeletedChildCount",
+                            str);
+        g_free (str);
+
+        g_object_notify (G_OBJECT (container), "total-deleted-child-count");
+}
+
+/**
+ * gupnp_didl_lite_container_unset_total_deleted_child_count:
+ * @container: #GUPnPDIDLLiteContainer
+ *
+ * Unset the total deleted child count property of the @container.
+ **/
+void
+gupnp_didl_lite_container_unset_total_deleted_child_count
+                                        (GUPnPDIDLLiteContainer *container)
+{
+        xmlNode *xml_node;
+
+        g_return_if_fail (container != NULL);
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container));
+
+        xml_node = gupnp_didl_lite_object_get_xml_node
+                                        (GUPNP_DIDL_LITE_OBJECT (container));
+        xml_util_unset_child (xml_node, "totalDeletedChildCount");
+
+        g_object_notify (G_OBJECT (container), "total-deleted-child-count");
+}
+
 /**
  * gupnp_didl_lite_container_add_create_class:
  * @container: #GUPnPDIDLLiteContainer
  * @create_class: The createClass to add.
  *
- * Add a new create class to the @object. includeDerived defaults to "0".
+ * Add a new create class to the @container. includeDerived defaults to "0".
  *
  * Return value: None.
  **/
@@ -429,7 +763,7 @@ gupnp_didl_lite_container_add_create_class (
  * @include_derived: Whether object with dervied classes may be created in
  * this container or not.
  *
- * Add a new create class to the @object.
+ * Add a new create class to the @container.
  *
  * Return value: None.
  **/
@@ -470,7 +804,7 @@ gupnp_didl_lite_container_add_create_class_full (
  * @container: #GUPnPDIDLLiteContainer
  * @search_class: The searchClass to add.
  *
- * Add a new search class to the @object.
+ * Add a new search class to the @container.
  *
  * Return value: None.
  **/
@@ -490,7 +824,7 @@ gupnp_didl_lite_container_add_search_class (
  * @search_class: The searchClass to add.
  * @include_derived: includeDerived attribute of the DIDL
  *
- * Add a new search class to the @object.
+ * Add a new search class to the @container.
  *
  * Return value: None.
  **/
