@@ -32,6 +32,7 @@
 #include "gupnp-av.h"
 #include "gupnp-didl-lite-object-private.h"
 #include "xml-util.h"
+#include "gupnp-didl-lite-parser-private.h"
 
 G_DEFINE_TYPE (GUPnPDIDLLiteParser,
                gupnp_didl_lite_parser,
@@ -75,6 +76,16 @@ verify_didl_attributes (xmlNode *node)
         return xml_util_verify_attribute_is_boolean (node, "restricted");
 }
 
+static gboolean
+parse_elements (GUPnPDIDLLiteParser *parser,
+                xmlNode             *node,
+                GUPnPXMLDoc         *xml_doc,
+                xmlNs               *upnp_ns,
+                xmlNs               *dc_ns,
+                xmlNs               *dlna_ns,
+                gboolean             recursive,
+                GError             **error);
+
 static void
 gupnp_didl_lite_parser_init (GUPnPDIDLLiteParser *parser)
 {
@@ -189,18 +200,42 @@ gboolean
 gupnp_didl_lite_parser_parse_didl (GUPnPDIDLLiteParser *parser,
                                    const char          *didl,
                                    GError             **error)
+{
+        return gupnp_didl_lite_parser_parse_didl_recursive (parser,
+                                                            didl,
+                                                            FALSE,
+                                                            error);
+}
+
+/**
+ * gupnp_didl_lite_parser_parse_didl_recursive:
+ * @parser: A #GUPnPDIDLLiteParser
+ * @didl: The DIDL-Lite XML string to be parsed
+ * @error: The location where to store any error, or NULL
+ *
+ * Parses DIDL-Lite XML string @didl, emitting the ::object-available,
+ * ::item-available and ::container-available signals appropriately during the
+ * process.
+ *
+ * Return value: TRUE on success.
+ **/
+gboolean
+gupnp_didl_lite_parser_parse_didl_recursive (GUPnPDIDLLiteParser *parser,
+                                             const char          *didl,
+                                             gboolean             recursive,
+                                             GError             **error)
 {
         xmlDoc       *doc;
         xmlNode      *element;
-        xmlNode      *node;
         xmlNs       **ns_list;
         xmlNs        *upnp_ns = NULL;
         xmlNs        *dc_ns   = NULL;
         xmlNs        *dlna_ns   = NULL;
         GUPnPXMLDoc  *xml_doc;
+        gboolean      result;
 
         doc = xmlRecoverMemory (didl, strlen (didl));
-	if (doc == NULL) {
+        if (doc == NULL) {
                 g_set_error (error,
                              GUPNP_XML_ERROR,
                              GUPNP_XML_ERROR_PARSE,
@@ -284,7 +319,32 @@ gupnp_didl_lite_parser_parse_didl (GUPnPDIDLLiteParser *parser,
 
         xml_doc = gupnp_xml_doc_new (doc);
 
-        for (element = element->children; element; element = element->next) {
+        result = parse_elements (parser,
+                                 element,
+                                 xml_doc,
+                                 upnp_ns,
+                                 dc_ns,
+                                 dlna_ns,
+                                 recursive,
+                                 error);
+        g_object_unref (xml_doc);
+
+        return result;
+}
+
+static gboolean
+parse_elements (GUPnPDIDLLiteParser *parser,
+                xmlNode             *node,
+                GUPnPXMLDoc         *xml_doc,
+                xmlNs               *upnp_ns,
+                xmlNs               *dc_ns,
+                xmlNs               *dlna_ns,
+                gboolean             recursive,
+                GError             **error)
+{
+        xmlNode *element;
+
+        for (element = node->children; element; element = element->next) {
                 GUPnPDIDLLiteObject *object;
 
                 object = gupnp_didl_lite_object_new_from_xml (element, xml_doc,
@@ -294,41 +354,49 @@ gupnp_didl_lite_parser_parse_didl (GUPnPDIDLLiteParser *parser,
                 if (object == NULL)
                         continue;
 
-                if (GUPNP_IS_DIDL_LITE_CONTAINER (object))
+                if (GUPNP_IS_DIDL_LITE_CONTAINER (object)) {
                         g_signal_emit (parser,
-                                        signals[CONTAINER_AVAILABLE],
-                                        0,
-                                        object);
-                else if (GUPNP_IS_DIDL_LITE_ITEM (object)) {
-                        node = gupnp_didl_lite_object_get_xml_node(object);
-                        if (!verify_didl_attributes(node)) {
-                            g_object_unref (object);
-                            g_object_unref (xml_doc);
-                            g_set_error (error,
-                                         GUPNP_XML_ERROR,
-                                         GUPNP_XML_ERROR_INVALID_ATTRIBUTE,
-                                         "Could not parse DIDL-Lite XML:\n%s",
-                                         didl);
+                                       signals[CONTAINER_AVAILABLE],
+                                       0,
+                                       object);
+                        if (recursive &&
+                            !parse_elements (parser,
+                                             element,
+                                             xml_doc,
+                                             upnp_ns,
+                                             dc_ns,
+                                             dlna_ns,
+                                             recursive,
+                                             error)) {
+                                g_object_unref (object);
 
-                            return FALSE;
+                                return FALSE;
+                        }
+                } else if (GUPNP_IS_DIDL_LITE_ITEM (object)) {
+                        node = gupnp_didl_lite_object_get_xml_node (object);
+                        if (!verify_didl_attributes (node)) {
+                                g_object_unref (object);
+                                g_set_error (error,
+                                             GUPNP_XML_ERROR,
+                                             GUPNP_XML_ERROR_INVALID_ATTRIBUTE,
+                                             "Could not parse DIDL-Lite XML");
+
+                                return FALSE;
                         }
 
                         g_signal_emit (parser,
-                                        signals[ITEM_AVAILABLE],
-                                        0,
-                                        object);
+                                       signals[ITEM_AVAILABLE],
+                                       0,
+                                       object);
                 }
 
                 g_signal_emit (parser,
-                                signals[OBJECT_AVAILABLE],
-                                0,
-                                object);
+                               signals[OBJECT_AVAILABLE],
+                               0,
+                               object);
 
                 g_object_unref (object);
         }
 
-        g_object_unref (xml_doc);
-
         return TRUE;
 }
-
